@@ -50,14 +50,6 @@ grunt.initConfig({
 		},
 		gruntfile: [ "Gruntfile.js" ],
 		dist: [ "dist/*.js" ],
-		addons: {
-			options: {
-				jshintrc: "addons/.jshintrc"
-			},
-			files: {
-				src: [ "addons/**/*.js" ]
-			}
-		},
 		tests: {
 			options: {
 				jshintrc: "test/.jshintrc"
@@ -76,7 +68,7 @@ grunt.initConfig({
 		]
 	},
 	watch: {
-		files: [ "*", ".jshintrc", "{addons,src,test}/**/{*,.*}" ],
+		files: [ "*", ".jshintrc", "{src,test}/**/{*,.*}" ],
 		tasks: "default"
 	}
 });
@@ -106,7 +98,7 @@ grunt.registerTask( "testswarm", function( commit, configFile ) {
 			name: "Commit <a href='https://github.com/jquery/qunit/commit/" + commit + "'>" +
 				commit.substr( 0, 10 ) + "</a>",
 			runs: runs,
-			browserSets: config.browserSets
+			browserSets: [ "popular", "ios" ]
 		}, function( err, passed ) {
 			if ( err ) {
 				grunt.log.error( err );
